# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['starro']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['coverage = scripts:coverage',
                     'lint = scripts:lint',
                     'security = scripts:security',
                     'test = scripts:test']}

setup_kwargs = {
    'name': 'starro',
    'version': '1.0.1',
    'description': 'The package objective is to mischaracterize sensitive data from this through blinding masks using asterisk',
    'long_description': None,
    'author': 'Marcos Borges',
    'author_email': 'contato@marcosborges.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



from . import starro
import re


def test_complete():
    assert starro.complete("1234567890") == "**********"


def test_password():
    assert starro.password("P@ssW0rd$@") == "**********"


def test_token():
    assert starro.token("1231asdasd321a3d21654asd") == "************************"


def test_accesskey():
    assert starro.accesskey("321a3d21654as") == "*************"


def test_secret():
    assert starro.secret("6543d21a2") == "*********"


def test_ssn():
    assert starro.ssn("517-90-0243") == "******-0243"


def test_phone():
    assert starro.phone("+55 (11) 9999-9999") == "+** (**) ****-9999"
    

def test_name():
    assert starro.name("Marcos Monteiro Borges") == "M***** M******* B*****"


def test_mail():
    assert starro.mail("contato@marcosborges.com") == "c******@marcosborges.com"


def test_cpf():
    assert starro.cpf("313.789.874-45") == "313.***.***-45"


def test_rg():
    assert starro.rg("34.275.057-4") == "34.***.***-4"


def test_pis():
    assert starro.pis("969.84160.68-4") == "969.*****.**-4"


def test_votercard():
    assert starro.votercard("266547320108") == "266******108"


def test_ie():
    assert starro.ie("009.186.436.570") == "009.***.***.570"


def test_cnh():
    assert starro.cnh("019647647710") == "019*******10"


def test_gender():
    assert starro.gender("male") == '****'


def test_address():
    assert starro.address("7086 S. Trout Rd. West Islip, NY 11795") == '**** S. Trout Rd. West Islip, NY *****'


def test_ethnicity():
    assert starro.ethnicity("italian") == '*******'


def test_religion():
    assert starro.religion("buddhist") == "********"


def test_health():
    assert starro.health("blood A+") == "********"


def test_politic():
    assert starro.politic("anarchist") == "*********"


def test_bank_number():
    assert starro.bank_number("1719") == "17**"


def test_account_number():
    assert starro.account_number("1719396-1") == "17*****-*"


def test_platecar():
    assert starro.platecar("IAF-9941") == "IAF-***1"


def test_creditcard():
    assert starro.creditcard("6666-0000-8888-3232") == "6666-****-****-3232"


def test_sexual():
    assert starro.sexual("heterosexual") == "************"


def test_crm():
    assert starro.crm("A054008") == "A***008"


def test_oab():
    assert starro.oab("UF999999") == "UF****99"


def test_mask_left():
    assert starro.mask_left("Testing mask left", 3) == "***ting mask left"


def test_mask_right():
    assert starro.mask_right("Testing mask right", 3) == "Testing mask ri***"


def test_fix_left():
    assert starro.fix_left("Testing fix left", 3) == "Tes*************"


def test_fix_right():
    assert starro.fix_right("Testing fix right", 3) == "**************ght"


def test_mask_center():
    assert starro.mask_center('completeds', 5) == 'com*****eds'


def test_mask_center_oversize():
    assert starro.mask_center('completeds', 12) == '**********'


def test_fix_center():
    assert starro.fix_center('complete', 4) == '**mple**'


def test_fix_center_oversize():
    assert starro.fix_center('complete', 12) == '********'


def test_starrofy():
    starro.starrofy('complete')
    assert True


def test_starrofy_decorator():
    
    starrofy = starro.starrofy('complete')
    
    def fn2(fn):
        return ""
    
    def fn(fn2):
        return ""

    starrofy(fn(fn2))
    assert True


import re
import math


def complete(arg):
    """Turns all characters to an string

    Args:
        arg (str): string to be converted

    Returns:
        str: converted string on string
    """
    return '*' * len(arg)


def password(arg):
    return complete(arg)


def token(arg):
    return complete(arg)


def accesskey(arg):
    return complete(arg)


def secret(arg):
    return complete(arg)


def ssn(arg):
    return fix_right(arg, 5)


def phone(arg):
    count = re.sub(r'\d', '*', arg).count('*') - 4
    return re.sub(r'\d', '*', arg, count=count)


def name(arg):
    return re.sub(r'\B([^\W])', '*', arg)


def cpf(arg):
    count = re.sub(r'\d', '*', arg).count('*') - 5
    return arg[:3] + re.sub(r'\d', '*', arg[3:], count=count)


# pylint: disable=C0103
def rg(arg):
    return arg[:3] + re.sub(r'\d', '*', arg[3:], count=6)


def pis(arg):
    return arg[:3] + re.sub(r'\d', '*', arg[3:], count=7)


def votercard(arg):
    return arg[:3] + re.sub(r'\d', '*', arg[3:], count=6)


# pylint: disable=C0103
def ie(arg):
    return arg[:3] + re.sub(r'\d', '*', arg[3:], count=6)


def cnh(arg):
    count = re.sub(r'\d', '*', arg).count('*') - 5
    return arg[:3] + re.sub(r'\d', '*', arg[3:], count=count)


def mail(arg):
    pattern = r'(?<=.)[^@](?=[^@]*?@)|(?:(?<=@.)|(?!^)\\G(?=[^@]*$)).(?=.*\\.)'
    return re.sub(pattern, "*", arg)


def gender(arg):
    return complete(arg)


def address(arg):
    return re.sub(r'\d', '*', arg)


def ethnicity(arg):
    return complete(arg)


def religion(arg):
    return complete(arg)


def health(arg):
    return complete(arg)


def politic(arg):
    return complete(arg)


def bank_number(arg):
    return arg[:2] + re.sub(r'\d', '*', arg[2:])


def account_number(arg):
    return arg[:2] + re.sub(r'\d', '*', arg[2:])


def platecar(arg):
    return re.sub(r'\d', '*', arg[:len(arg)-1]) + arg[len(arg)-1:]


def creditcard(arg):
    return arg[:4] + re.sub(r'\d', '*', arg[4:], count=8)


def sexual(arg):
    return complete(arg)


def crm(arg):
    return arg[:1] + re.sub(r'\d', '*', arg[1:], count=3)


def oab(arg):
    return arg[:2] + re.sub(r'\d', '*', arg[2:], count=4)


def mask_left(arg, size):
    return '*' * size + arg[size:]


def mask_right(arg, size):
    return arg[:(len(arg)-size)] + '*' * size


def mask_center(arg, size):
    total = len(arg)
    if total < size:
        return '*' * total
    result = math.ceil((total - size) / 2)
    return arg[:result] + ('*' * (len(arg) - size)) + arg[-result:]


def fix_left(arg, size):
    return arg[:size] + ('*' * (len(arg) - size))


def fix_right(arg, size):
    return ('*' * (len(arg) - size)) + arg[-size:]


def fix_center(arg, size):
    total = len(arg)
    if total < size:
        return '*' * total
    start = math.ceil((total - size) / 2)
    end = math.floor((total - size) / 2)

    return ('*' * start) + arg[start:-end] + ('*' * end)


# pylint: disable=W0123
def starrofy(filter_name):
    def decorator(func):
        def wrapper(*args, **kwargs):
            result = func(*args, **kwargs)
            # pylint: disable=global-statement
            return eval(filter_name + '("' + result + '")')
        return wrapper
    return decorator
